.. py:module:: bcdi.utils

.. toctree::
   :maxdepth: 2

:mod:`bcdi.utils`: various utilities for DFT registration and subpixel shift, data loading and fitting, validating parameters
=============================================================================================================================

utilities
^^^^^^^^^

Various non-specific utilities for i/o, fitting curves, generic functions for cropping
or padding a dataset...

API Reference
-------------

.. automodule:: bcdi.utils.utilities
   :members:

image_registration 
^^^^^^^^^^^^^^^^^^

Functions related to image registration and the alignment of datasets in direct or
reciprocal space.

API Reference
-------------

.. automodule:: bcdi.utils.image_registration
   :members:

validation
^^^^^^^^^^

This module contains all validation functions that are used throughout the code, in
order to test the input parameters of functions.

API Reference
-------------

.. automodule:: bcdi.utils.validation
   :members:
